==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_comparer' => 'Ver las diferencias',

	// D
	'diff_para_ajoute' => 'Párrafo añadido',
	'diff_para_deplace' => 'Párrafo desplazado',
	'diff_para_supprime' => 'Párrafo suprimido',
	'diff_texte_ajoute' => 'Texto añadido',
	'diff_texte_deplace' => 'Texto desplazado',
	'diff_texte_supprime' => 'Texto suprimido',
	'differences_versions' => 'Diferencias entre versión N<sup>o</sup>@id_version@ y version N<sup>o</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Restaurar la versión N<sup>o</sup>@version@',
	'icone_suivi_revisions' => 'Seguimiento de revisiones',
	'info_1_revision' => '1 revisión',
	'info_aucune_revision' => 'Ninguna revisión',
	'info_historique' => 'Revisiones :',
	'info_historique_lien' => 'Mostrar el historial de modificaciones',
	'info_historique_titre' => 'Seguimiento de revisiones',
	'info_nb_revisions' => '@nb@ revisiones',

	// L
	'label_choisir_id_version' => 'Selecciona las versiones para comparar',
	'label_config_revisions_objets' => 'Sobre qué objetos activar las revisiones:',

	// M
	'message_valider_recuperer_version' => 'Valida el formulario para volver a esta versión.',

	// O
	'objet_editorial' => 'objeto',

	// P
	'plugin_update' => 'Actualización del plugin "Revisioness" a la versión @version@.',

	// T
	'titre_form_revisions_objets' => 'Activar las revisiones',
	'titre_restaurer_version' => 'Restaurar una versión',
	'titre_revisions' => 'Revisiones',

	// V
	'version_deplace_rubrique' => 'Desplazado de <b>« @from@ »</b> a <b>« @to@ »</b>.',
	'version_initiale' => 'Versión inicial',
	'voir_differences' => 'Ver las diferencias',
	'voir_mes_revisions' => 'Mis revisiones',
	'voir_revisions' => 'Ver las revisiones (@objet@ @id_objet@ : @titre@)',
	'voir_toutes_les_revisions' => 'Todas las revisiones'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_comparer' => 'Ver las diferencias',

	// D
	'diff_para_ajoute' => 'Párrafo añadido',
	'diff_para_deplace' => 'Párrafo desplazado',
	'diff_para_supprime' => 'Párrafo suprimido',
	'diff_texte_ajoute' => 'Texto añadido',
	'diff_texte_deplace' => 'Texto desplazado',
	'diff_texte_supprime' => 'Texto suprimido',
	'differences_versions' => 'Diferencias entre versión N<sup>o</sup>@id_version@ y version N<sup>o</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Restaurar la versión N<sup>o</sup>@version@',
	'icone_suivi_revisions' => 'Seguimiento de revisiones',
	'info_1_revision' => '1 revisión',
	'info_aucune_revision' => 'Ninguna revisión',
	'info_historique' => 'Revisiones :',
	'info_historique_lien' => 'Mostrar el historial de modificaciones',
	'info_historique_titre' => 'Seguimiento de revisiones',
	'info_nb_revisions' => '@nb@ revisiones',

	// L
	'label_choisir_id_version' => 'Selecciona las versiones para comparar',
	'label_config_revisions_objets' => 'Sobre qué objetos activar las revisiones:',

	// M
	'message_valider_recuperer_version' => 'Valida el formulario para volver a esta versión.',

	// O
	'objet_editorial' => 'objeto',

	// P
	'plugin_update' => 'Actualización del plugin "Revisioness" a la versión @version@.',

	// T
	'titre_form_revisions_objets' => 'Activar las revisiones',
	'titre_restaurer_version' => 'Restaurar una versión',
	'titre_revisions' => 'Revisiones',

	// V
	'version_deplace_rubrique' => 'Desplazado de <b>« @from@ »</b> a <b>« @to@ »</b>.',
	'version_initiale' => 'Versión inicial',
	'voir_differences' => 'Ver las diferencias',
	'voir_mes_revisions' => 'Mis revisiones',
	'voir_revisions' => 'Ver las revisiones (@objet@ @id_objet@ : @titre@)',
	'voir_toutes_les_revisions' => 'Todas las revisiones',
];
